==> videojs-playlist-ui-3.5.2.jar: META-INF/resources/webjars/videojs-playlist-ui/3.5.2/CHANGELOG.md <==
<a name="3.5.2"></a>
## [3.5.2](https://github.com/brightcove/videojs-playlist-ui/compare/v3.5.1...v3.5.2) (2018-10-03)

### Bug Fixes

* Remove the playlist UI when the player is disposed. ([#81](https://github.com/brightcove/videojs-playlist-ui/issues/81)) ([c519585](https://github.com/brightcove/videojs-playlist-ui/commit/c519585))
* Remove the postinstall script to prevent install issues ([#76](https://github.com/brightcove/videojs-playlist-ui/issues/76)) ([fbe09e2](https://github.com/brightcove/videojs-playlist-ui/commit/fbe09e2))

### Chores

* update to generator-videojs-plugin[@7](https://github.com/7).2.0 ([0235fee](https://github.com/brightcove/videojs-playlist-ui/commit/0235fee))
* **package:** update rollup to version 0.66.0 ([#79](https://github.com/brightcove/videojs-playlist-ui/issues/79)) ([dc86980](https://github.com/brightcove/videojs-playlist-ui/commit/dc86980))

<a name="3.5.1"></a>
## [3.5.1](https://github.com/brightcove/videojs-playlist-ui/compare/v3.5.0...v3.5.1) (2018-08-23)

### Chores

* generator v7 ([#72](https://github.com/brightcove/videojs-playlist-ui/issues/72)) ([c8cb58d](https://github.com/brightcove/videojs-playlist-ui/commit/c8cb58d))

<a name="3.5.0"></a>
# [3.5.0](https://github.com/brightcove/videojs-playlist-ui/compare/v3.4.2...v3.5.0) (2018-08-20)

### Features

* set dataset attributes on playlist items when they have a data object ([#68](https://github.com/brightcove/videojs-playlist-ui/issues/68)) ([e16f2dd](https://github.com/brightcove/videojs-playlist-ui/commit/e16f2dd))

<a name="3.4.2"></a>
## [3.4.2](https://github.com/brightcove/videojs-playlist-ui/compare/v3.4.1...v3.4.2) (2018-08-03)

### Bug Fixes

* babel the es dist, by updating the generator ([#65](https://github.com/brightcove/videojs-playlist-ui/issues/65)) ([f63f77b](https://github.com/brightcove/videojs-playlist-ui/commit/f63f77b))

### Chores

* **package:** update dependencies, enable greenkeeper ([#62](https://github.com/brightcove/videojs-playlist-ui/issues/62)) ([63a89a7](https://github.com/brightcove/videojs-playlist-ui/commit/63a89a7))

<a name="3.4.1"></a>
## [3.4.1](https://github.com/brightcove/videojs-playlist-ui/compare/v3.0.7...v3.4.1) (2018-07-20)

### Bug Fixes

* css builds ([#63](https://github.com/brightcove/videojs-playlist-ui/issues/63)) ([603ec73](https://github.com/brightcove/videojs-playlist-ui/commit/603ec73))

### Reverts

* unintended pkg changes ([#64](https://github.com/brightcove/videojs-playlist-ui/issues/64)) ([be83683](https://github.com/brightcove/videojs-playlist-ui/commit/be83683))

<a name="3.0.8"></a>
## [3.0.8](https://github.com/brightcove/videojs-playlist-ui/compare/v3.0.6...v3.0.8) (2018-07-20)

### Bug Fixes

* update rollup to fix test build ([d329710](https://github.com/brightcove/videojs-playlist-ui/commit/d329710))
* revert: generator update from 3.0.7

<a name="3.0.7"></a>
## [3.0.7](https://github.com/brightcove/videojs-playlist-ui/compare/v3.4.0...v3.0.7) (2018-07-05)

### Chores

* generator v6 ([#58](https://github.com/brightcove/videojs-playlist-ui/issues/58)) ([e9c2b00](https://github.com/brightcove/videojs-playlist-ui/commit/e9c2b00))

<a name="3.4.0"></a>
# [3.4.0](https://github.com/brightcove/videojs-playlist-ui/compare/v3.3.0...v3.4.0) (2018-03-29)

### Features

* Expose the version of the plugin at the `VERSION` property. ([#56](https://github.com/brightcove/videojs-playlist-ui/issues/56)) ([cb2da9d](https://github.com/brightcove/videojs-playlist-ui/commit/cb2da9d))

### Bug Fixes

* Truncate longer video titles with ellipses when they overflow ([#57](https://github.com/brightcove/videojs-playlist-ui/issues/57)) ([18d8a18](https://github.com/brightcove/videojs-playlist-ui/commit/18d8a18))

### Chores

* Update tooling via the plugin generator. ([#55](https://github.com/brightcove/videojs-playlist-ui/issues/55)) ([b753ab3](https://github.com/brightcove/videojs-playlist-ui/commit/b753ab3))

<a name="3.3.0"></a>
# [3.3.0](https://github.com/brightcove/videojs-playlist-ui/compare/v3.2.1...v3.3.0) (2017-12-04)

### Features

* Support horizontal playlist display. ([#54](https://github.com/brightcove/videojs-playlist-ui/issues/54)) ([85965b6](https://github.com/brightcove/videojs-playlist-ui/commit/85965b6))

<a name="3.2.1"></a>
## [3.2.1](https://github.com/brightcove/videojs-playlist-ui/compare/v3.2.0...v3.2.1) (2017-11-29)

### Bug Fixes

* Do not concatenate playlist items if the plugin is re-initialized. ([#53](https://github.com/brightcove/videojs-playlist-ui/issues/53)) ([7953ad6](https://github.com/brightcove/videojs-playlist-ui/commit/7953ad6))

<a name="3.2.0"></a>
# [3.2.0](https://github.com/brightcove/videojs-playlist-ui/compare/v3.1.0...v3.2.0) (2017-11-29)

### Features

* Support the 'playlistsorted' event added in videojs-playlist 4.1.0. ([#52](https://github.com/brightcove/videojs-playlist-ui/issues/52)) ([6d79ac1](https://github.com/brightcove/videojs-playlist-ui/commit/6d79ac1))

<a name="3.1.0"></a>
# [3.1.0](https://github.com/brightcove/videojs-playlist-ui/compare/v3.0.6...v3.1.0) (2017-11-15)

### Features

* Better support for multiple in-page players by more intelligently finding a player's associated playlist element. ([#50](https://github.com/brightcove/videojs-playlist-ui/issues/50)) ([50bd97c](https://github.com/brightcove/videojs-playlist-ui/commit/50bd97c))

<a name="3.0.6"></a>
## [3.0.6](https://github.com/brightcove/videojs-playlist-ui/compare/v3.0.5...v3.0.6) (2017-09-05)

### Bug Fixes

* breaking changed caused by dist files being renamed ([#46](https://github.com/brightcove/videojs-playlist-ui/issues/46)) ([52140f4](https://github.com/brightcove/videojs-playlist-ui/commit/52140f4))
* simplify removal of vjs-ad-playing class ([#45](https://github.com/brightcove/videojs-playlist-ui/issues/45)) ([b49dc82](https://github.com/brightcove/videojs-playlist-ui/commit/b49dc82))

<a name="3.0.5"></a>
## [3.0.5](https://github.com/brightcove/videojs-playlist-ui/compare/v3.0.3...v3.0.5) (2017-05-19)

### Chores

* Update tooling using generator v5 prerelease. ([#42](https://github.com/brightcove/videojs-playlist-ui/issues/42)) ([6153b64](https://github.com/brightcove/videojs-playlist-ui/commit/6153b64))

# CHANGELOG

## 3.0.4

* @incompl Fix collision in CSS
* @incompl Fix accessibility for image thumbnails

## 3.0.3

* chore: @brandonocasey Fix Video.js 6 deprecation warnings
* chore: @brandonocasey Update unit tests to use karma

## 3.0.2

* @misteroneill More complete documentation and examples

## 3.0.1

* @misteroneill Update videojs-playlist to v3.0.0 [#24](https://github.com/brightcove/videojs-playlist-ui/pull/24)
* @diniscorreia Fix documentation for placeholder element [#30](https://github.com/brightcove/videojs-playlist-ui/pull/30)
* @diniscorreia Fix querySelector for list creation [#29](https://github.com/brightcove/videojs-playlist-ui/pull/29)

## 3.0.0

* Redesigned UI. Bigger thumbnails, more room for video titles, and more.

## 2.3.1

* @misteroneill More complete documentation and examples [#32](https://github.com/brightcove/videojs-playlist-ui/pull/32)
* @misteroneill Update to videojs-playlist 3.0.0 [#31](https://github.com/brightcove/videojs-playlist-ui/pull/31)

## 2.3.0

* Keep vjs-ad-playing class after postroll until ended event

## 2.2.0

* Fixup babelify and have a proper browserify endpoint

...

## 0.1.0

* Initial release

==> videojs-playlist-ui-3.8.0.jar: META-INF/resources/webjars/videojs-playlist-ui/3.8.0/CHANGELOG.md <==
<a name="3.8.0"></a>
# [3.8.0](https://github.com/brightcove/videojs-playlist-ui/compare/v3.7.0...v3.8.0) (2020-05-06)

### Features

* Enabling option to display video descriptions in playlist thumb… ([#129](https://github.com/brightcove/videojs-playlist-ui/issues/129)) ([b3fbc84](https://github.com/brightcove/videojs-playlist-ui/commit/b3fbc84))

<a name="3.7.0"></a>
# [3.7.0](https://github.com/brightcove/videojs-playlist-ui/compare/v3.6.0...v3.7.0) (2020-02-08)

### Features

* **lang:** Add Arabic translations ([#121](https://github.com/brightcove/videojs-playlist-ui/issues/121)) ([2e820a3](https://github.com/brightcove/videojs-playlist-ui/commit/2e820a3))

### Chores

* **package:** Update all dev dependencies ([#122](https://github.com/brightcove/videojs-playlist-ui/issues/122)) ([90d6135](https://github.com/brightcove/videojs-playlist-ui/commit/90d6135))

<a name="3.6.0"></a>
# [3.6.0](https://github.com/brightcove/videojs-playlist-ui/compare/v3.5.2...v3.6.0) (2019-08-26)

### Features

* Add translations for localizable strings ([#107](https://github.com/brightcove/videojs-playlist-ui/issues/107)) ([96b5ef7](https://github.com/brightcove/videojs-playlist-ui/commit/96b5ef7))

### Chores

* **package:** Update dependencies to fix npm audit issues ([#106](https://github.com/brightcove/videojs-playlist-ui/issues/106)) ([ec20321](https://github.com/brightcove/videojs-playlist-ui/commit/ec20321))
* **package:** update lint-staged to version 8.1.0 ([#91](https://github.com/brightcove/videojs-playlist-ui/issues/91)) ([afd859e](https://github.com/brightcove/videojs-playlist-ui/commit/afd859e))
* **package:** update npm-run-all/videojs-generator-verify for security ([9c579e0](https://github.com/brightcove/videojs-playlist-ui/commit/9c579e0))
* **package:** update rollup to version 0.67.3 ([#89](https://github.com/brightcove/videojs-playlist-ui/issues/89)) ([d969e5d](https://github.com/brightcove/videojs-playlist-ui/commit/d969e5d))
* **package:** update videojs-generate-karma-config to version 5.0.0 ([#90](https://github.com/brightcove/videojs-playlist-ui/issues/90)) ([841cc2d](https://github.com/brightcove/videojs-playlist-ui/commit/841cc2d))
* **package:** update videojs-generate-rollup-config to version 2.3.1 ([#92](https://github.com/brightcove/videojs-playlist-ui/issues/92)) ([ee3a461](https://github.com/brightcove/videojs-playlist-ui/commit/ee3a461))
* **package:** update videojs-standard to version 8.0.2 ([#93](https://github.com/brightcove/videojs-playlist-ui/issues/93)) ([d9066ea](https://github.com/brightcove/videojs-playlist-ui/commit/d9066ea))

<a name="3.5.2"></a>
## [3.5.2](https://github.com/brightcove/videojs-playlist-ui/compare/v3.5.1...v3.5.2) (2018-10-03)

### Bug Fixes

* Remove the playlist UI when the player is disposed. ([#81](https://github.com/brightcove/videojs-playlist-ui/issues/81)) ([c519585](https://github.com/brightcove/videojs-playlist-ui/commit/c519585))
* Remove the postinstall script to prevent install issues ([#76](https://github.com/brightcove/videojs-playlist-ui/issues/76)) ([fbe09e2](https://github.com/brightcove/videojs-playlist-ui/commit/fbe09e2))

### Chores

* update to generator-videojs-plugin[@7](https://github.com/7).2.0 ([0235fee](https://github.com/brightcove/videojs-playlist-ui/commit/0235fee))
* **package:** update rollup to version 0.66.0 ([#79](https://github.com/brightcove/videojs-playlist-ui/issues/79)) ([dc86980](https://github.com/brightcove/videojs-playlist-ui/commit/dc86980))

<a name="3.5.1"></a>
## [3.5.1](https://github.com/brightcove/videojs-playlist-ui/compare/v3.5.0...v3.5.1) (2018-08-23)

### Chores

* generator v7 ([#72](https://github.com/brightcove/videojs-playlist-ui/issues/72)) ([c8cb58d](https://github.com/brightcove/videojs-playlist-ui/commit/c8cb58d))

<a name="3.5.0"></a>
# [3.5.0](https://github.com/brightcove/videojs-playlist-ui/compare/v3.4.2...v3.5.0) (2018-08-20)

### Features

* set dataset attributes on playlist items when they have a data object ([#68](https://github.com/brightcove/videojs-playlist-ui/issues/68)) ([e16f2dd](https://github.com/brightcove/videojs-playlist-ui/commit/e16f2dd))

<a name="3.4.2"></a>
## [3.4.2](https://github.com/brightcove/videojs-playlist-ui/compare/v3.4.1...v3.4.2) (2018-08-03)

### Bug Fixes

* babel the es dist, by updating the generator ([#65](https://github.com/brightcove/videojs-playlist-ui/issues/65)) ([f63f77b](https://github.com/brightcove/videojs-playlist-ui/commit/f63f77b))

### Chores

* **package:** update dependencies, enable greenkeeper ([#62](https://github.com/brightcove/videojs-playlist-ui/issues/62)) ([63a89a7](https://github.com/brightcove/videojs-playlist-ui/commit/63a89a7))

<a name="3.4.1"></a>
## [3.4.1](https://github.com/brightcove/videojs-playlist-ui/compare/v3.0.7...v3.4.1) (2018-07-20)

### Bug Fixes

* css builds ([#63](https://github.com/brightcove/videojs-playlist-ui/issues/63)) ([603ec73](https://github.com/brightcove/videojs-playlist-ui/commit/603ec73))

### Reverts

* unintended pkg changes ([#64](https://github.com/brightcove/videojs-playlist-ui/issues/64)) ([be83683](https://github.com/brightcove/videojs-playlist-ui/commit/be83683))

<a name="3.0.8"></a>
## [3.0.8](https://github.com/brightcove/videojs-playlist-ui/compare/v3.0.6...v3.0.8) (2018-07-20)

### Bug Fixes

* update rollup to fix test build ([d329710](https://github.com/brightcove/videojs-playlist-ui/commit/d329710))
* revert: generator update from 3.0.7

<a name="3.0.7"></a>
## [3.0.7](https://github.com/brightcove/videojs-playlist-ui/compare/v3.4.0...v3.0.7) (2018-07-05)

### Chores

* generator v6 ([#58](https://github.com/brightcove/videojs-playlist-ui/issues/58)) ([e9c2b00](https://github.com/brightcove/videojs-playlist-ui/commit/e9c2b00))

<a name="3.4.0"></a>
# [3.4.0](https://github.com/brightcove/videojs-playlist-ui/compare/v3.3.0...v3.4.0) (2018-03-29)

### Features

* Expose the version of the plugin at the `VERSION` property. ([#56](https://github.com/brightcove/videojs-playlist-ui/issues/56)) ([cb2da9d](https://github.com/brightcove/videojs-playlist-ui/commit/cb2da9d))

### Bug Fixes

* Truncate longer video titles with ellipses when they overflow ([#57](https://github.com/brightcove/videojs-playlist-ui/issues/57)) ([18d8a18](https://github.com/brightcove/videojs-playlist-ui/commit/18d8a18))

### Chores

* Update tooling via the plugin generator. ([#55](https://github.com/brightcove/videojs-playlist-ui/issues/55)) ([b753ab3](https://github.com/brightcove/videojs-playlist-ui/commit/b753ab3))

<a name="3.3.0"></a>
# [3.3.0](https://github.com/brightcove/videojs-playlist-ui/compare/v3.2.1...v3.3.0) (2017-12-04)

### Features

* Support horizontal playlist display. ([#54](https://github.com/brightcove/videojs-playlist-ui/issues/54)) ([85965b6](https://github.com/brightcove/videojs-playlist-ui/commit/85965b6))

<a name="3.2.1"></a>
## [3.2.1](https://github.com/brightcove/videojs-playlist-ui/compare/v3.2.0...v3.2.1) (2017-11-29)

### Bug Fixes

* Do not concatenate playlist items if the plugin is re-initialized. ([#53](https://github.com/brightcove/videojs-playlist-ui/issues/53)) ([7953ad6](https://github.com/brightcove/videojs-playlist-ui/commit/7953ad6))

<a name="3.2.0"></a>
# [3.2.0](https://github.com/brightcove/videojs-playlist-ui/compare/v3.1.0...v3.2.0) (2017-11-29)

### Features

* Support the 'playlistsorted' event added in videojs-playlist 4.1.0. ([#52](https://github.com/brightcove/videojs-playlist-ui/issues/52)) ([6d79ac1](https://github.com/brightcove/videojs-playlist-ui/commit/6d79ac1))

<a name="3.1.0"></a>
# [3.1.0](https://github.com/brightcove/videojs-playlist-ui/compare/v3.0.6...v3.1.0) (2017-11-15)

### Features

* Better support for multiple in-page players by more intelligently finding a player's associated playlist element. ([#50](https://github.com/brightcove/videojs-playlist-ui/issues/50)) ([50bd97c](https://github.com/brightcove/videojs-playlist-ui/commit/50bd97c))

<a name="3.0.6"></a>
## [3.0.6](https://github.com/brightcove/videojs-playlist-ui/compare/v3.0.5...v3.0.6) (2017-09-05)

### Bug Fixes

* breaking changed caused by dist files being renamed ([#46](https://github.com/brightcove/videojs-playlist-ui/issues/46)) ([52140f4](https://github.com/brightcove/videojs-playlist-ui/commit/52140f4))
* simplify removal of vjs-ad-playing class ([#45](https://github.com/brightcove/videojs-playlist-ui/issues/45)) ([b49dc82](https://github.com/brightcove/videojs-playlist-ui/commit/b49dc82))

<a name="3.0.5"></a>
## [3.0.5](https://github.com/brightcove/videojs-playlist-ui/compare/v3.0.3...v3.0.5) (2017-05-19)

### Chores

* Update tooling using generator v5 prerelease. ([#42](https://github.com/brightcove/videojs-playlist-ui/issues/42)) ([6153b64](https://github.com/brightcove/videojs-playlist-ui/commit/6153b64))

# CHANGELOG

## 3.0.4

* @incompl Fix collision in CSS
* @incompl Fix accessibility for image thumbnails

## 3.0.3

* chore: @brandonocasey Fix Video.js 6 deprecation warnings
* chore: @brandonocasey Update unit tests to use karma

## 3.0.2

* @misteroneill More complete documentation and examples

## 3.0.1

* @misteroneill Update videojs-playlist to v3.0.0 [#24](https://github.com/brightcove/videojs-playlist-ui/pull/24)
* @diniscorreia Fix documentation for placeholder element [#30](https://github.com/brightcove/videojs-playlist-ui/pull/30)
* @diniscorreia Fix querySelector for list creation [#29](https://github.com/brightcove/videojs-playlist-ui/pull/29)

## 3.0.0

* Redesigned UI. Bigger thumbnails, more room for video titles, and more.

## 2.3.1

* @misteroneill More complete documentation and examples [#32](https://github.com/brightcove/videojs-playlist-ui/pull/32)
* @misteroneill Update to videojs-playlist 3.0.0 [#31](https://github.com/brightcove/videojs-playlist-ui/pull/31)

## 2.3.0

* Keep vjs-ad-playing class after postroll until ended event

## 2.2.0

* Fixup babelify and have a proper browserify endpoint

...

## 0.1.0

* Initial release
